<?php

namespace App\Http\Controllers\AdminAuth;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Session;
use Yajra\Datatables\Datatables;
use App\Model\File;
use Illuminate\Support\Facades\Auth;

class FileController extends Controller
{
    private $data = array(
        'route' => 'admin.file.',
        'title' => 'File',
        'menu' => 'file',
        'submenu' => '',
    );
	
    public function __construct()
    {
        //$this->middleware('auth');
        $this->middleware(['permission:publish |file add|file edit|file delete']);
    }
	
    private function _validate($request, $id = null)
    {
        $this->validate($request, [
            //'name' => 'required|email',
            'image' => (!empty($id)?'':'required'),
        ]);
    }

    public function index(Request $request)
    {

        if ($request->ajax()) {
            $records = File::with('category')->select('*');
            return Datatables::of($records)
                ->filter(function ($query) use ($request) {
                    if ($request->has('short_status')) {
                        $query->where('status', '=', "{$request->get('short_status')}");
                    }
                    if ($request->has('short_category')) {
                        $query->where('category_id', '=', "{$request->get('short_category')}");
                    }
                })
                //return $this->dataTable->eloquent($records) 
                ->addColumn('image', function ($record) {
                    if(!empty($record['thumb_image_url'])){
                        return '<a href= "'. url($record->thumb_image_url).'" target="_blank" ><img src="'.$record->thumb_image_url.'" width="150" ></a>';
                    }else if(!empty($record['image_url'])){
                        return '<a href= "'. url($record->image_url).'" target="_blank" ><img src="'.$record->image_url.'" width="150" ></a>';
                    }
                    else{
                        return 'Image not found';
                    }
                })
                ->addColumn('image_size', function ($record) {
                    if(file_exists('./storage/' . $record['image'])){
                        $original =  !empty($record['image']) ? FileSizeConvert(filesize('./storage/' . $record['image'])) : '';
                    }else{
                        $original = 'Not found';
                    }
                    if(file_exists('./storage/thumb/' . $record['image'])){
                        $thumb =  !empty($record['image']) ? FileSizeConvert(filesize('./storage/thumb/' . $record['image'])) : '';
                    }else{
                        $thumb = 'Not found';
                    }
                    return 'O : '.$original.'<br/>'.'T : '.$thumb;
                    
                })
                ->editColumn('created_at', function ($record) {
                    return $record->created_at->format(config('app.display_date'));
                })
                
                ->addColumn('status', function ($record) {
                    return '<input id="toggle-demo" value="' . $record->id . '" class="chk_status" data-toggle="toggle" data-on="Active" data-off="Inactive" data-size="small" data-onstyle="success"  type="checkbox" ' . ($record->status == "Active" ? " checked" : "" ) . ' >';
                })
                ->addColumn('action', function ($record) {
                    return '<a href="' . route($this->data['route'] . 'show', ['id' => $record->id]) . '" class="btn btn-primary btn-sm" title="" data-toggle="tooltip" data-original-title="View"><i class="fa fa-eye-slash"></i></a>' .
                            '&nbsp;<a href="' . route($this->data['route'] . 'edit', ['id' => $record->id]) . '" class="btn btn-info btn-sm" title="" data-toggle="tooltip" data-original-title="Edit"><i class="fa fa-pencil"></i></a>' .
                            '&nbsp;<button class="btn btn-danger btn-sm data-delete" data-id="' . $record->id . '" data-toggle="tooltip" data-original-title="Delete"><i class="fa fa-trash"></i></button>';
                })
                ->rawColumns(['status','action','image','image_size'])
                ->make(true);
        }

        //$this->data['records'] = File::all();
        $this->data['count_total'] = File::count();
        $this->data['count_active'] = File::where('status','Active')->count();
        $this->data['count_inactive'] = File::where('status','Inactive')->count();
        
        return view('admin.file.index',$this->data);

    }

    public function create()
    {
        abort_unless(Auth::guard('admin')->user()->hasAnyPermission(['file add']), 403);
        return view('admin.file.create',$this->data);
    }


    public function store(Request $request)
    {
        //return $request->file('image');
        abort_unless(Auth::guard('admin')->user()->hasAnyPermission(['file add']), 403);
        //$this->_validate($request);
        $input = $request->all();
        $input['status'] = 'Inactive';
        $input['image'] = $this->uploadFile2($request, null, 'file', 'file',true,650 );
        $input['video'] = $this->uploadFile($request, null, 'video', 'video' );
        $record =  new File($input);
        $record->save();

        Session::flash('success', $this->data['title'].' inserted successfully.');
        if ($request->ajax()) {
            return \Illuminate\Support\Facades\Response::json([
                'result'=>'success','url' => route($this->data['route'].'create')]);
        }
        return redirect()->route($this->data['route'].'index');
    }


    public function show($id)
    {
        return $this->data['record'] = File::findOrFail($id);
        return view('admin.file.show',$this->data);
    }


    public function edit($id)
    {
        abort_unless(Auth::guard('admin')->user()->hasAnyPermission(['file edit']), 403);
        $this->data['record'] = File::findOrFail($id);
        return view('admin.file.create',$this->data);
    }


    public function update(Request $request, $id)
    {
        
        abort_unless(Auth::guard('admin')->user()->hasAnyPermission(['file edit']), 403);
        $record = File::findOrFail($id);
        /* Change Status Block */
        if ($request->ajax() && !empty($request['status'])) {
            $record->update($request->only(['status']));
            return \Illuminate\Support\Facades\Response::json(['result'=>'success']);
        }

        $this->_validate($request,$id);
        $input = $request->all();
        $input['image'] = $this->uploadFile2($request, $record, 'image', 'file',true,650);
        $input['video'] = $this->uploadFile($request, $record, 'video', 'video');
        if (empty($input['image'])) {unset($input['image']);}
        if (empty($input['video'])) {unset($input['video']);}
        $record->update($input);

        Session::flash('info', $this->data['title'].' updated successfully.');
        if ($request->ajax()) {
            return \Illuminate\Support\Facades\Response::json([
                'result'=>'success','url' => route($this->data['route'].'edit',['id'=>$id])]);
        }
        return redirect()->route($this->data['route'].'index');
    }


    public function destroy($id)
    {
        abort_unless(Auth::guard('admin')->user()->hasAnyPermission(['file delete']), 403);
        $record = File::findOrFail($id);
        $this->deleteFile($record,'image',true);
        $this->deleteFile($record,'video');
        $record->delete();
        return \Illuminate\Support\Facades\Response::json(['result'=>'success','message'=>'Deleted Data successfully!']);
    }
    
    public function multiple_file(Request $request){
        //return $request->all();
        return view('admin.file.multiple', $this->data);
    }
    public function multiple_file_all(Request $request){
        //return $request->all();
        $query = File::query();
        if(!empty($request['category_id'])){
            $query->where('category_id',$request['category_id']);
        }
        
        $records = $query->paginate(8);
        $this->data['records'] = $records;
        return view('admin.file.multiple_all', $this->data);
    }
    public function multiple_file_post(Request $request){
        /*return $request->all();
        echo '<pre>';
        print_r($_FILES);
        die;
        $input = $request->all();*/
        
        $input = \Illuminate\Support\Facades\Input::all();
        $rules = array(
            'file' => 'image|max:2000',
        );

        $validation = \Illuminate\Support\Facades\Validator::make($input, $rules);

        if ($validation->fails())
        {
                return \Illuminate\Support\Facades\Response::json('error: file less than 2MB', 400);
        }
        
        $input['status'] = 'Inactive';
        $input['category_id'] = $request['category_id'];
        $input['image'] = $this->uploadFile2($request, null, 'file', 'file',true,650);
        
        $record =  new File($input);
        $record->save();
        return \Illuminate\Support\Facades\Response::json('success', 200);
        //return $request->all();
    }
}
