<?php

namespace App\Http\Controllers\AdminAuth;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Session;
use Yajra\Datatables\Datatables;
use App\Model\Gallery;

class GalleryController extends Controller
{
    private $data = array(
        'route' => 'admin.gallery.',
        'title' => 'Gallery',
        'menu' => 'gallery',
        'submenu' => '',
    );
	
    public function __construct()
    {
       //$this->middleware('auth');
    }
	
    private function _validate($request, $id = null)
    {
        $this->validate($request, [
			//'image' => (!empty($id)?'mimes:jpeg,png,jpg,gif,svg|max:2048':'required|mimes:jpeg,png,jpg,gif,svg|max:2048'),
        ]);
    }

    public function index(Request $request)
    {
        if ($request->ajax()) {
            $records = Gallery::select('galleries.*');
			 
            return Datatables::of($records)
			    ->addIndexColumn()
				->editColumn('created_at', function ($record) {
				    return $record->created_at->format('d-m-Y');
			    })
			    ->addColumn('image', function ($record) {
					if(!empty($record['image_url'])){
						return '<a href= "'. url($record->image_url).'" target="_blank" ><img src="'.$record->image_url.'" width="100" ></a>';
					}else{
						return '';
					}
				})
				->addColumn('image_size', function ($record) {
                        if (file_exists('./storage/' . $record['image'])) {
                            $original = !empty($record['image']) ? FileSizeConvert(filesize('./storage/' . $record['image'])) : '';
                        } else {
                            $original = 'Not found';
                        }
                        if (file_exists('./storage/thumb/' . $record['image'])) {
                            $thumb = !empty($record['image']) ? FileSizeConvert(filesize('./storage/thumb/' . $record['image'])) : '';
                        } else {
                            $thumb = 'Not found';
                        }
                        return 'O : ' . $original . '<br/>' . 'T : ' . $thumb;
                    })
                ->addColumn('status', function ($record) {
                    return '<input id="toggle-demo" value="'.$record->id.'" class="chk_status" data-toggle="toggle" data-on="Active" data-off="Inactive" data-size="small" data-onstyle="success"  type="checkbox" '.($record->status == "Active"?" checked":"" ).' >';
                })
                ->addColumn('action', function ($record) {
                    return /*'<a href="'.route($this->data['route'].'show',['id' =>$record->id]).'" class="btn btn-primary btn-sm" title="" data-toggle="tooltip" data-original-title="View"><i class="fa fa-eye-slash"></i></a>'.*/
                          '&nbsp;<a href="'.route($this->data['route'].'edit',['id' =>$record->id]).'" class="btn btn-info btn-sm" title="" data-toggle="tooltip" data-original-title="Edit"><i class="fa fa-pencil"></i></a>'.
                          '&nbsp;<button class="btn btn-danger btn-sm data-delete" data-id="'.$record->id.'" data-toggle="tooltip" data-original-title="Delete"><i class="fa fa-trash"></i></button>';
                })
                ->rawColumns(['status','action','image','image_size'])
                ->make(true);
        }

        //$this->data['records'] = Gallery::all();
        return view('admin.gallery.index',$this->data);

    }

    public function create()
    {
		return view('admin.gallery.create',$this->data);
    }


    public function store(Request $request)
    {
        $this->_validate($request);
		$input = $request->all();
		$input['image'] = $this->uploadFile($request, null, 'image', 'gallery', true, 650);
        $record =  new Gallery($input);
		$record->save();
        Session::flash('success', $this->data['title'].' inserted successfully.');
        return redirect()->route($this->data['route'].'index');
    }


    public function show($id)
    {
        $this->data['record'] = Gallery::findOrFail($id);
		
        return view('admin.gallery.show',$this->data);
    }


    public function edit($id)
    {
        $this->data['record'] = Gallery::findOrFail($id);
		
        return view('admin.gallery.create',$this->data);
    }


    public function update(Request $request, $id)
    {
        $record = Gallery::findOrFail($id);
        /* Change Status Block */
        if ($request->ajax()) {
            $record->update($request->all());
            return \Illuminate\Support\Facades\Response::json(['result' => 'success']);
        }
		$this->_validate($request, $id);
        $input = $request->all();
		
		$input['set_home_page'] = isset($request['set_home_page'])?$request['set_home_page']:'no';
        $input['image'] = $this->uploadFile($request, $record, 'image', 'gallery', TRUE, 650);
        if (empty($input['image'])) {
            unset($input['image']);
        }
        $record->update($input);

        Session::flash('info', $this->data['title'].' updated successfully.');
        return redirect()->route($this->data['route'].'index');
    }


    public function destroy($id)
    {
        $record = Gallery::findOrFail($id);
		$this->deleteFile($record,'image',true);
        $record->delete();
        return \Illuminate\Support\Facades\Response::json(['result'=>'success','message'=>'Deleted Data successfully!']);
    }
}
