<?php

namespace App\Http\Controllers\AdminAuth;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Carbon\Carbon;

class HomeController extends Controller
{
    private $data = array(
        'controller' => 'AdminAuth\HomeController',
        'title' => 'Home',
        'menu' => 'home',
        'submenu' => '',
    );

    public function __construct()
    {
        $this->middleware('admin');
    }

    public function index(){
        return view('admin.home.home',$this->data);
    }
    public function analytics(){
        abort_unless(Auth::guard('admin')->user()->hasAnyPermission(['analytics']), 403);

        $this->data['menu'] = 'analytics';
        $this->data['total_device'] = \App\User::selectRaw('COUNT(id) as total,device')->groupBy(['device'])->get();
        $this->data['total_registered'] = \App\User::whereNotNull('email')->count();
        $this->data['total_unregistered'] = \App\User::whereNull('email')->count();
        
        

        return view('admin.analytics',$this->data);
    }
    
    public function analytics_data(Request $request){
        //return $request->all();
        $date_start = date('Y-m-d', strtotime($request['start_date']));
        $date_end = date('Y-m-d', strtotime($request['end_date']));
        $group_by ='';
        $grpb = $request['group_by'];
        
        
        switch ($grpb) {
            case 'month':
                $date_format = 'Y-m';
                $post_fix = '-01 23:59:59';
                $label_format = 'M, Y';
                $select = 'date_format(created_at,"%Y-%m") as label_date, count(id) as record_count';
                $group_by = 'year(created_at),month(created_at)';
                break;
            case 'year':
                $date_format = 'Y';
                $post_fix = '-01-01 23:59:59';
                $label_format = 'Y';
                $select = 'year(created_at) as label_date, count(id) as record_count';
                $group_by = 'year(created_at)';
                break;
            default :
                $grpb = 'day';
                $date_format = 'Y-m-d';
                $post_fix = ' 23:59:59';
                $label_format = 'M j';
                $select = 'date(created_at) as label_date, count(id) as record_count';
                $group_by = 'date(created_at)';
        }
        
        $android = \App\User::query()
                ->where([
                    ['created_at', '>=', Carbon::parse($date_start . ' 00:00:00')->timezone('UTC')],
                    ['created_at', '<=', Carbon::parse($date_end . ' 23:59:59')->timezone('UTC')],
                ])
                ->select(DB::raw($select))
                ->where('device','android')
                ->groupBy(DB::raw($group_by))
                ->get()->keyBy('label_date');
        $ios = \App\User::query()
                ->where([
                    ['created_at', '>=', Carbon::parse($date_start . ' 00:00:00')->timezone('UTC')],
                    ['created_at', '<=', Carbon::parse($date_end . ' 23:59:59')->timezone('UTC')],
                ])
                ->select(DB::raw($select))
                ->where('device','ios')
                ->groupBy(DB::raw($group_by))
                ->get()->keyBy('label_date');

        
        $increment = ' + 1 ' . $grpb;
        $result = [];
        while ($date_start  <  $date_end){
            $data1 = !empty($android[$date_start])?$android[$date_start]['record_count']:0;
            $data2 = !empty($ios[$date_start])?$ios[$date_start]['record_count']:0;
            $result[$date_start] = [
                'label' => Carbon::parse($date_start . $post_fix)->format($label_format),
                'android' => $data1,
                'ios' => $data2,
                'total' => $data1 + $data2,
            ];
            $date_start = Carbon::parse($date_start . $post_fix . $increment)->format($date_format);
        }
        
        //return '123';
        return $result;
    }
    
    public function analytics_upload_data(Request $request){
        //return $request->all();
        $date_start = date('Y-m-d', strtotime($request['start_date']));
        $date_end = date('Y-m-d', strtotime($request['end_date']));
        $group_by ='';
        $grpb = $request['group_by'];
        
        
        switch ($grpb) {
            case 'month':
                $date_format = 'Y-m';
                $post_fix = '-01 23:59:59';
                $label_format = 'M, Y';
                $select = 'date_format(created_at,"%Y-%m") as label_date, count(id) as record_count';
                $group_by = 'year(created_at),month(created_at)';
                break;
            case 'year':
                $date_format = 'Y';
                $post_fix = '-01-01 23:59:59';
                $label_format = 'Y';
                $select = 'year(created_at) as label_date, count(id) as record_count';
                $group_by = 'year(created_at)';
                break;
            default :
                $grpb = 'day';
                $date_format = 'Y-m-d';
                $post_fix = ' 23:59:59';
                $label_format = 'M j';
                $select = 'date(created_at) as label_date, count(id) as record_count';
                $group_by = 'date(created_at)';
        }
        
        $files = \App\Model\File::query()
                ->where([
                    ['created_at', '>=', Carbon::parse($date_start . ' 00:00:00')->timezone('UTC')],
                    ['created_at', '<=', Carbon::parse($date_end . ' 23:59:59')->timezone('UTC')],
                ])
                ->select(DB::raw($select))
                ->groupBy(DB::raw($group_by))
                ->get()->keyBy('label_date');
        
        
        $increment = ' + 1 ' . $grpb;
        $result = [];
        while ($date_start  <  $date_end){
            $data1 = !empty($files[$date_start])?$files[$date_start]['record_count']:0;
            $data2 = !empty($ios[$date_start])?$ios[$date_start]['record_count']:0;
            $result[$date_start] = [
                'label' => Carbon::parse($date_start . $post_fix)->format($label_format),
                'file' => $data1,
            ];
            $date_start = Carbon::parse($date_start . $post_fix . $increment)->format($date_format);
        }
        
        //return '123';
        return $result;
    }
    
    
}
