<?php

namespace App\Http\Controllers\AdminAuth;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Session;
use Yajra\Datatables\Datatables;
use App\Model\Brand;
use App\Model\Inquiry;

class InquiryController extends Controller
{
    private $data = array(
        'route' => 'admin.inquiry.',
        'title' => 'Inquiry',
        'menu' => 'inquiry',
        'submenu' => '',
    );
	
    public function __construct()
    {
       //$this->middleware('auth');
    }
	
    private function _validate($request, $id = null)
    {
        $this->validate($request, [
			//'image' => (!empty($id)?'mimes:jpeg,png,jpg,gif,svg|max:2048':'required|mimes:jpeg,png,jpg,gif,svg|max:2048'),
        ]);
    }

    public function index(Request $request)
    {
        if ($request->ajax()) {
            $records = Inquiry::with('flight')->select('inquiries.*')->orderBy('inquiries.id','desc');
			
            return Datatables::of($records)
			    ->addIndexColumn()
				->editColumn('created_at', function ($record) {
				    return $record->created_at->format('d-m-Y');
			    })
			
				
                ->addColumn('action', function ($record) {
                    return 
                          '<button class="btn btn-danger btn-sm data-delete" data-id="'.$record->id.'" data-toggle="tooltip" data-original-title="Delete"><i class="fa fa-trash"></i></button>';
                })
                ->rawColumns(['action','name'])
                ->make(true);
        }

        //$this->data['records'] = Brand::all();
        return view('admin.inquiry.index',$this->data);

    }

    public function create()
    {
		return view('admin.inquiry.create',$this->data);
    }


    public function store(Request $request)
    {
        $this->_validate($request);
		$input = $request->all();
		$input['image'] = $this->uploadFile($request, null, 'image', 'brand', false);
        $record =  new Brand($input);
		$record->save();
        Session::flash('success', $this->data['title'].' inserted successfully.');
        return redirect()->route($this->data['route'].'index');
    }


    public function show($id)
    {
        $this->data['record'] = Brand::findOrFail($id);
		
        return view('admin.inquiry.show',$this->data);
    }


    public function edit($id)
    {
        $this->data['record'] = Brand::findOrFail($id);
		
        return view('admin.inquiry.create',$this->data);
    }


    public function update(Request $request, $id)
    {
        $record = Brand::findOrFail($id);
        /* Change Status Block */
        if ($request->ajax()) {
            $record->update($request->all());
            return \Illuminate\Support\Facades\Response::json(['result' => 'success']);
        }
		$this->_validate($request, $id);
        $input = $request->all();
		
        $input['image'] = $this->uploadFile($request, $record, 'image', 'brand', false);
        if (empty($input['image'])) {
            unset($input['image']);
        }
        $record->update($input);

        Session::flash('info', $this->data['title'].' updated successfully.');
        return redirect()->route($this->data['route'].'index');
    }


    public function destroy($id)
    {
        $record = Inquiry::findOrFail($id);
        $record->delete();
        return \Illuminate\Support\Facades\Response::json(['result'=>'success','message'=>'Deleted Data successfully!']);
    }
}
