<?php

namespace App\Http\Controllers\AdminAuth;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Session;
use Yajra\Datatables\Datatables;
use App\Model\Message;

class MessageController extends Controller
{
    private $data = array(
        'route' => 'admin.message.',
        'title' => 'Message',
        'menu' => 'message',
        'submenu' => '',
    );
	
    public function __construct()
    {
        //$this->middleware('auth');
        $this->middleware(['permission:publish |message']);
    }
	
    private function _validate($request, $id = null)
    {
        $this->validate($request, [
            'title' => 'required|max:255',
            'message' => 'required|max:255',
        ]);
    }

    public function index(Request $request)
    {

        if ($request->ajax()) {
            $records = Message::select('*');
			
            return Datatables::of($records)
              //return $this->dataTable->eloquent($records) 
                      
                ->editColumn('created_at', function ($record) {
                    return $record->created_at->format(config('app.display_date'));
                })
                
                ->editColumn('notify_time', function ($record) {
                    return \Carbon\Carbon::parse($record['notify_time'])->format(config('app.display_date'));
                })
                
                ->addColumn('ios_completed', function ($record) {
                    if($record['ios']=='0'){
                        return 'N/A';
                    }elseif($record['ios_completed']){
                        return '<small class="label  bg-green">success</small>';
                    }else{
                        return 'pending';
                    }
                })
                ->addColumn('android_completed', function ($record) {
                    if($record['android'] == '0'){
                        return 'N/A';
                    }elseif($record['android_completed']){
                        return '<small class="label  bg-green">success</small>';
                    }else{
                        return 'pending';                                                
                    }
                })
                ->addColumn('action', function ($record) {
                    if( ($record['ios']=='1' && $record['ios_completed'] == '0') || ($record['android']=='1' && $record['android_completed'] == '0') || ($record['ios']=='0' && $record['android']=='0') ){
                        return '&nbsp;<a href="'.route($this->data['route'].'edit',['id' =>$record->id]).'" class="btn btn-info btn-sm" title="" data-toggle="tooltip" data-original-title="Edit"><i class="fa fa-pencil"></i></a>'.
                          '&nbsp;<button class="btn btn-danger btn-sm data-delete" data-id="'.$record->id.'" data-toggle="tooltip" data-original-title="Delete"><i class="fa fa-trash"></i></button>';
                    }else{
                        return '';
                    }
                })
                ->rawColumns(['ios_completed','android_completed','action'])
                ->make(true);
        }

        //$this->data['records'] = Message::all();
        return view('admin.message.index',$this->data);

    }

    public function create()
    {
        return view('admin.message.create',$this->data);
    }


    public function store(Request $request)
    {
        /*return $request->all();
        if(!isset($request['ios'])){
            
        }*/
        $this->_validate($request);
        $request['notify_time'] = \Carbon\Carbon::parse($request['date'].' '.$request['time']);
        $record =  new Message($request->all());
        $record->save();

        Session::flash('success', $this->data['title'].' inserted successfully.');
        return redirect()->route($this->data['route'].'index');
    }


    public function show($id)
    {
        $this->data['record'] = Message::findOrFail($id);
        return view('admin.message.show',$this->data);
    }


    public function edit($id)
    {
        $this->data['record'] = Message::findOrFail($id);
        return view('admin.message.create',$this->data);
    }


    public function update(Request $request, $id)
    {
        $request['ios'] = isset($request['ios'])?$request['ios']:'0';
        $request['android'] = isset($request['android'])?$request['android']:'0';
        $record = Message::findOrFail($id);
        /* Change Status Block */
        if ($request->ajax()) {
            $record->update($request->only(['status']));
            return \Illuminate\Support\Facades\Response::json(['result'=>'success']);
        }

        $this->_validate($request,$id);
        $request['notify_time'] = \Carbon\Carbon::parse($request['date'].' '.$request['time']);
        $record->update($request->all());

        Session::flash('info', $this->data['title'].' updated successfully.');
        return redirect()->route($this->data['route'].'index');
    }


    public function destroy($id)
    {
        $record = Message::findOrFail($id);
        $record->delete();
        return \Illuminate\Support\Facades\Response::json(['result'=>'success','message'=>'Deleted Data successfully!']);
    }
}
