
<!DOCTYPE html>
<html>
<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
</head>
<body>
<?php 
    function convert_number_to_words($number) {

        $hyphen      = '-';
        $conjunction = ' and ';
        $separator   = ', ';
        $negative    = 'negative ';
        $decimal     = ' point ';
        $dictionary  = array(
            0                   => 'zero',
            1                   => 'one',
            2                   => 'two',
            3                   => 'three',
            4                   => 'four',
            5                   => 'five',
            6                   => 'six',
            7                   => 'seven',
            8                   => 'eight',
            9                   => 'nine',
            10                  => 'ten',
            11                  => 'eleven',
            12                  => 'twelve',
            13                  => 'thirteen',
            14                  => 'fourteen',
            15                  => 'fifteen',
            16                  => 'sixteen',
            17                  => 'seventeen',
            18                  => 'eighteen',
            19                  => 'nineteen',
            20                  => 'twenty',
            30                  => 'thirty',
            40                  => 'fourty',
            50                  => 'fifty',
            60                  => 'sixty',
            70                  => 'seventy',
            80                  => 'eighty',
            90                  => 'ninety',
            100                 => 'hundred',
            1000                => 'thousand',
            1000000             => 'million',
            1000000000          => 'billion',
            1000000000000       => 'trillion',
            1000000000000000    => 'quadrillion',
            1000000000000000000 => 'quintillion'
        );
    
        if (!is_numeric($number)) {
            return false;
        }
    
        if (($number >= 0 && (int) $number < 0) || (int) $number < 0 - PHP_INT_MAX) {
            // overflow
            trigger_error(
                'convert_number_to_words only accepts numbers between -' . PHP_INT_MAX . ' and ' . PHP_INT_MAX,
                E_USER_WARNING
            );
            return false;
        }
    
        if ($number < 0) {
            return $negative . convert_number_to_words(abs($number));
        }
    
        $string = $fraction = null;
    
        if (strpos($number, '.') !== false) {
            list($number, $fraction) = explode('.', $number);
        }
    
        switch (true) {
            case $number < 21:
                $string = $dictionary[$number];
                break;
            case $number < 100:
                $tens   = ((int) ($number / 10)) * 10;
                $units  = $number % 10;
                $string = $dictionary[$tens];
                if ($units) {
                    $string .= $hyphen . $dictionary[$units];
                }
                break;
            case $number < 1000:
                $hundreds  = $number / 100;
                $remainder = $number % 100;
                $string = $dictionary[$hundreds] . ' ' . $dictionary[100];
                if ($remainder) {
                    $string .= $conjunction . convert_number_to_words($remainder);
                }
                break;
            default:
                $baseUnit = pow(1000, floor(log($number, 1000)));
                $numBaseUnits = (int) ($number / $baseUnit);
                $remainder = $number % $baseUnit;
                $string = convert_number_to_words($numBaseUnits) . ' ' . $dictionary[$baseUnit];
                if ($remainder) {
                    $string .= $remainder < 100 ? $conjunction : $separator;
                    $string .= convert_number_to_words($remainder);
                }
                break;
        }
    
        if (null !== $fraction && is_numeric($fraction)) {
            $string .= $decimal;
            $words = array();
            foreach (str_split((string) $fraction) as $number) {
                $words[] = $dictionary[$number];
            }
            $string .= implode(' ', $words);
        }
    
        return $string;
    }
    

    
    class IndianCurrency{ 
    
      public function __construct($amount){
        $this->amount=$amount;
        $this->hasPaisa=false;
        $arr=explode(".",$this->amount);
        $this->rupees=$arr[0];
        if(isset($arr[1])&&((int)$arr[1])>0){
          if(strlen($arr[1])>2){
            $arr[1]=substr($arr[1],0,2);
          }
          $this->hasPaisa=true;
          $this->paisa=$arr[1];
        }
      }
      
      public function get_words(){
        $w="";
        $crore=(int)($this->rupees/10000000);
        $this->rupees=$this->rupees%10000000;
        $w.=$this->single_word($crore,"Crore ");
        $lakh=(int)($this->rupees/100000);
        $this->rupees=$this->rupees%100000;
        $w.=$this->single_word($lakh,"Lakh ");
        $thousand=(int)($this->rupees/1000);
        $this->rupees=$this->rupees%1000;
        $w.=$this->single_word($thousand,"Thousand  ");
        $hundred=(int)($this->rupees/100);
        $w.=$this->single_word($hundred,"Hundred ");
        $ten=$this->rupees%100;
        $w.=$this->single_word($ten,"");
        $w.="Rupees ";
        if($this->hasPaisa){
          if($this->paisa[0]=="0"){
            $this->paisa=(int)$this->paisa;
          }
          else if(strlen($this->paisa)==1){
            $this->paisa=$this->paisa*10;
          }
          $w.=" and ".$this->single_word($this->paisa," Paisa");
        }
        return $w." Only";
      }
    
      private function single_word($n,$txt){
        $t="";
        if($n<=19){
          $t=$this->words_array($n);
        }else{
          $a=$n-($n%10);
          $b=$n%10;
          $t=$this->words_array($a)."".$this->words_array($b);
        }
        if($n==0){
          $txt="";
        }
        return $t." ".$txt;
      }
    
      private function words_array($num){
        $n=[0=>"", 1=>"One", 2=>"Two", 3=>"Three", 4=>"Four", 5=>"Five", 6=>"Six", 7=>"Seven", 8=>"Eight", 9=>"Nine", 10=>"Ten", 11=>"Eleven", 12=>"Twelve", 13=>"Thirteen", 14=>"Fourteen", 15=>"Fifteen", 16=>"Sixteen", 17=>"Seventeen", 18=>"Eighteen", 19=>"Nineteen", 20=>"Twenty", 30=>"Thirty", 40=>"Forty", 50=>"Fifty", 60=>"Sixty", 70=>"Seventy", 80=>"Eighty", 90=>"Ninety", 100=>"Hundred",];
        return $n[$num];
      }
    }
    ?>






<table style="width: 100%; padding-bottom: 20px;">
    <tr style="width: 100%; ">
        <th style="width: 30%; text-align: left;" rowspan="5"><img src="https://abdgtravels.com/public/assets/design/images/BABA.png" width="30%" ></th>
        <td style="color: #38739e; font-size: 24px; padding-left: 270px; padding-bottom: 5px;">Abdg Travels</td>
    </tr>

    <tr>
        <td style="font-size: 10px; padding-left: 270px;"><B>Mobile:</B> <?php echo e($sitesetting->comp_phone); ?></td>
    </tr>

    <tr>
        <td style="font-size: 10px; padding-left: 270px;"><B>Web:</B> www.abdgtravels.com</td>
    </tr>

    <tr>
        <td style="font-size: 10px; padding-left: 270px;"><B>Email:</B>  <?php echo e($sitesetting->comp_email); ?></td>
    </tr>

    <tr style="">
        <td style="font-size: 10px; padding-left: 270px;"><B>Address:</B> <?php echo e($sitesetting->comp_address); ?></td>
    </tr>
</table>

<table style="width: 100%; border: 1px solid black;">
    <tr style="border: 1px solid black; ">
        <th style="width: 60%; font-size: 10px; text-align: left; border-bottom: 1px solid black; border-right: 1px solid black;">Recipient Detalis</th>
        <th style="width: 40%; font-size: 10px; text-align: left; border-bottom: 1px solid black;">Original</th>
    </tr>

    <tr style="width: 100%;">
        <th style="width: 60%; border-right: 1px solid black; font-size: 10px; text-align: left; padding-bottom: 20px;">NAME:- <?php echo e($booking->billing_name); ?></tH>
        <th style="width: 40%; font-size: 10px; text-align: left; padding-top: -15px;">Tax Invoice No:-</tH>
    </tr>

    <tr style="width: 100%;">
        <th style="width: 60%; border-right: 1px solid black; font-size: 10px; text-align: left;">ADDRESS:- <?php echo e($booking->billing_address); ?></tH>
        <th style="width: 40%; font-size: 10px; text-align: left; padding-top: -30px;">Date:-<?php echo e(date('d-m-Y',strtotime($booking->created_at))); ?></tH>
    </tr>

    
</table>


<table style="width: 100%; border: 1px solid black; border-top: none;">
    <tr style="border: 1px solid black; ">
        <th style="width: 10%; font-size: 10px; text-align: left; border-bottom: 1px solid black; border-right: 1px solid black;">SR.NO.</th>
        <th style="width: 70%; font-size: 10px; text-align: left; border-bottom: 1px solid black; border-right: 1px solid black;">Itam</th>
        <th style="width: 20%; font-size: 10px; text-align: center; border-bottom: 1px solid black;">AMOUNT</th>
    </tr>

    <tr style="border: 1px solid black; ">
        <td style="width: 10%; font-size: 10px; text-align: left; border-bottom: 1px solid black; border-right: 1px solid black;">1</td>
        <td style="width: 70%; font-size: 10px; text-align: left; border-bottom: 1px solid black; border-right: 1px solid black;"><?php echo e($booking->cab_type); ?> <?php echo e($booking->cab_car); ?></td>
        <td style="width: 20%; font-size: 10px; text-align: center; border-bottom: 1px solid black;"><?php echo e($booking->amount); ?></td>
    </tr>

    <?php if($booking->voucher_discount): ?>
    <tr style="border: 1px solid black;">
        <td style="width: 10%; font-size: 10px; text-align: left;"></td>
        <th style="width: 70%; font-size: 10px; text-align: right; border-right: 1px solid black;">Discount</th>
        <td style="width: 20%; font-size: 10px; text-align: center;"><?php echo e($booking->voucher_discount); ?></td>
    </tr> 

    <?php endif; ?>
    
    <tr style="border: 1px solid black;">
        <td style="width: 10%; font-size: 10px; text-align: left;"></td>
        <th style="width: 70%; font-size: 10px; text-align: right; border-right: 1px solid black;">TOTAL</th>
        <td style="width: 20%; font-size: 10px; text-align: center;"><?php echo e($booking->grandtotal); ?></td>
    </tr>
</table>

<?php 
    	$obj=new IndianCurrency($booking->grandtotal );

        

 ?>
<table style="width: 100%; border: 1px solid black; border-top: none;">
    <tr style="border: 1px solid black; ">
        <th style="width: 60%; font-size: 10px; text-align: left; border-bottom: 1px solid black; border-right: 1px solid black;">Amount In World</th>
        <td style="width: 40%; font-size: 10px; text-align: left; border-bottom: 1px solid black;"><?php echo e($obj->get_words()); ?></td>
    </tr>

    <tr style="border: 1px solid black; ">
        <th style="width: 60%; font-size: 10px; text-align: left; border-right: 1px solid black;">Company Name:- <?php echo e($sitesetting->comp_name); ?></th>
        <th style="width: 40%; font-size: 10px; text-align: right;">For, <?php echo e($sitesetting->comp_name); ?></th>
    </tr>

    <tr style="border: 1px solid black; ">
        <td style="width: 60%; font-size: 10px; text-align: left; border-right: 1px solid black;"><b>Company's GST:-</b> <?php echo e($sitesetting->comp_gst); ?></td>
        <th style="width: 40%; font-size: 10px; text-align: left;"></th>
    </tr>

    <tr style="border: 1px solid black; ">
        <th style="width: 60%; font-size: 10px; text-align: left; border-right: 1px solid black;"></th>
        <th style="width: 40%; font-size: 10px; text-align: right; padding-top: 50px;">Authorised Signature</th>
    </tr>
</table>



</body>
</html>